/* -*- c++ -*- */
/*
 * Copyright 2012 Free Software Foundation, Inc.
 * Copyright 2012 Dimitri Stolnikov <horiz0n@gmx.net>
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */
#ifndef INCLUDED_OSMOSDR_SOURCE_C_IMPL_H
#define INCLUDED_OSMOSDR_SOURCE_C_IMPL_H

#include <osmosdr_api.h>
#include <osmosdr_source_c.h>

#include <rtl_source_c.h>

class OSMOSDR_API osmosdr_source_c_impl : public osmosdr_source_c
{
public:
  osmosdr::meta_range_t get_samp_rates( void );
  double set_samp_rate( double rate );
  double get_samp_rate( void );

  osmosdr::freq_range_t get_freq_range( size_t chan = 0 );
  double set_center_freq( double freq, size_t chan = 0 );
  double get_center_freq( size_t chan = 0 );
  double set_freq_correction( double ppm, size_t chan = 0 );
  double get_freq_correction( size_t chan = 0 );

  std::vector<std::string> get_gain_names( size_t chan = 0 );
  osmosdr::gain_range_t get_gain_range( const std::string & name = "", size_t chan = 0 );
  void set_gain( double gain, size_t chan = 0 );
  void set_gain( double gain, const std::string & name = "", size_t chan = 0 );
  double get_gain( const std::string & name = "", size_t chan = 0 );

private:
  osmosdr_source_c_impl (const std::string & args);  	// private constructor

  // The friend declaration allows osmosdr_make_source_c to
  // access the private constructor.
  friend OSMOSDR_API osmosdr_source_c_sptr osmosdr_make_source_c (const std::string & args);

  rtl_source_c_sptr _src;
};

#endif /* INCLUDED_OSMOSDR_SOURCE_C_IMPL_H */
